==> estateplat-common-1.2.3-20190301.025841-228-sources.jar: cn/gtmap/estateplat/model/server/core/BdcHy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 宗海
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_hy")
public class BdcHy implements Serializable ,InsertVo{
    @Id
    private String hyid;
    //宗地宗海号
    private String zdzhh;
    //面积单位
    private String mjdw;
    //单位代码
    private String dwdm;
    //街道（乡镇）号
    private String jdh;
    //街坊（村）号
    private String jfh;
    //组号
    private String zh;
    //坐落
    private String zl;
    //项目性质
    private String xmxz;
    //宗海面积
    private Double zhmj;
    //用海类型
    private String yhlx;
    //海域等别
    private Integer hydb;
    //占用岸线
    private String zyax;
    //状态:1、无效，0、有效
    private Integer zt;
    //用海总面积
    private Double yhzmj;
    //占用岸线单位
    private String zyaxdw;
    //用海类型A
    private String yhlxa;
    //用海类型B
    private String yhlxb;
    //用海位置说明
    private String yhwzsm;
    //海岛名称
    private String hdmc;
    //海岛代码
    private String hddm;
    //用岛范围
    private String ydfw;
    //用岛面积
    private Double ydmj;
    //海岛位置
    private String hdwz;
    //用途
    private String yt;

    public String getHyid() {
        return hyid;
    }

    public void setHyid(String hyid) {
        this.hyid = hyid;
    }

    public String getZdzhh() {
        return zdzhh;
    }

    public void setZdzhh(String zdzhh) {
        this.zdzhh = zdzhh;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getJdh() {
        return jdh;
    }

    public void setJdh(String jdh) {
        this.jdh = jdh;
    }

    public String getJfh() {
        return jfh;
    }

    public void setJfh(String jfh) {
        this.jfh = jfh;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getXmxz() {
        return xmxz;
    }

    public void setXmxz(String xmxz) {
        this.xmxz = xmxz;
    }

    public Double getZhmj() {
        return zhmj;
    }

    public void setZhmj(Double zhmj) {
        this.zhmj = zhmj;
    }

    public String getYhlx() {
        return yhlx;
    }

    public void setYhlx(String yhlx) {
        this.yhlx = yhlx;
    }

    public Integer getHydb() {
        return hydb;
    }

    public void setHydb(Integer hydb) {
        this.hydb = hydb;
    }

    public String getZyax() {
        return zyax;
    }

    public void setZyax(String zyax) {
        this.zyax = zyax;
    }

    public Integer getZt() {
        return zt;
    }

    public void setZt(Integer zt) {
        this.zt = zt;
    }

    public Double getYhzmj() {
        return yhzmj;
    }

    public void setYhzmj(Double yhzmj) {
        this.yhzmj = yhzmj;
    }

    public String getZyaxdw() {
        return zyaxdw;
    }

    public void setZyaxdw(String zyaxdw) {
        this.zyaxdw = zyaxdw;
    }

    public String getYhlxa() {
        return yhlxa;
    }

    public void setYhlxa(String yhlxa) {
        this.yhlxa = yhlxa;
    }

    public String getYhlxb() {
        return yhlxb;
    }

    public void setYhlxb(String yhlxb) {
        this.yhlxb = yhlxb;
    }

    public String getYhwzsm() {
        return yhwzsm;
    }

    public void setYhwzsm(String yhwzsm) {
        this.yhwzsm = yhwzsm;
    }

    public String getHdmc() {
        return hdmc;
    }

    public void setHdmc(String hdmc) {
        this.hdmc = hdmc;
    }

    public String getHddm() {
        return hddm;
    }

    public void setHddm(String hddm) {
        this.hddm = hddm;
    }

    public String getYdfw() {
        return ydfw;
    }

    public void setYdfw(String ydfw) {
        this.ydfw = ydfw;
    }

    public Double getYdmj() {
        return ydmj;
    }

    public void setYdmj(Double ydmj) {
        this.ydmj = ydmj;
    }

    public String getHdwz() {
        return hdwz;
    }

    public void setHdwz(String hdwz) {
        this.hdwz = hdwz;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }
}

==> estateplat-common-1.2.4-20220629.074349-1059-sources.jar: cn/gtmap/estateplat/model/server/core/BdcHy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * 宗海
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/11/1
 */
@Table(name = "bdc_hy")
public class BdcHy implements Serializable ,InsertVo{
    @Id
    private String hyid;
    //宗地宗海号
    private String zdzhh;
    //面积单位
    private String mjdw;
    //单位代码
    private String dwdm;
    //街道（乡镇）号
    private String jdh;
    //街坊（村）号
    private String jfh;
    //组号
    private String zh;
    //坐落
    private String zl;
    //项目性质
    private String xmxz;
    //宗海面积
    private Double zhmj;
    //用海类型
    private String yhlx;
    //海域等别
    private String hydb;
    //占用岸线
    private String zyax;
    //状态:1、无效，0、有效
    private Integer zt;
    //用海总面积
    private Double yhzmj;
    //占用岸线单位
    private String zyaxdw;
    //用海类型A
    private String yhlxa;
    //用海类型B
    private String yhlxb;
    //用海位置说明
    private String yhwzsm;
    //海岛名称
    private String hdmc;
    //海岛代码
    private String hddm;
    //用岛范围
    private String ydfw;
    //用岛面积
    private Double ydmj;
    //海岛位置
    private String hdwz;
    //用途
    private String yt;

    public String getHyid() {
        return hyid;
    }

    public void setHyid(String hyid) {
        this.hyid = hyid;
    }

    public String getZdzhh() {
        return zdzhh;
    }

    public void setZdzhh(String zdzhh) {
        this.zdzhh = zdzhh;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getJdh() {
        return jdh;
    }

    public void setJdh(String jdh) {
        this.jdh = jdh;
    }

    public String getJfh() {
        return jfh;
    }

    public void setJfh(String jfh) {
        this.jfh = jfh;
    }

    public String getZh() {
        return zh;
    }

    public void setZh(String zh) {
        this.zh = zh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getXmxz() {
        return xmxz;
    }

    public void setXmxz(String xmxz) {
        this.xmxz = xmxz;
    }

    public Double getZhmj() {
        return zhmj;
    }

    public void setZhmj(Double zhmj) {
        this.zhmj = zhmj;
    }

    public String getYhlx() {
        return yhlx;
    }

    public void setYhlx(String yhlx) {
        this.yhlx = yhlx;
    }

    public String getHydb() {
        return hydb;
    }

    public void setHydb(String hydb) {
        this.hydb = hydb;
    }

    public String getZyax() {
        return zyax;
    }

    public void setZyax(String zyax) {
        this.zyax = zyax;
    }

    public Integer getZt() {
        return zt;
    }

    public void setZt(Integer zt) {
        this.zt = zt;
    }

    public Double getYhzmj() {
        return yhzmj;
    }

    public void setYhzmj(Double yhzmj) {
        this.yhzmj = yhzmj;
    }

    public String getZyaxdw() {
        return zyaxdw;
    }

    public void setZyaxdw(String zyaxdw) {
        this.zyaxdw = zyaxdw;
    }

    public String getYhlxa() {
        return yhlxa;
    }

    public void setYhlxa(String yhlxa) {
        this.yhlxa = yhlxa;
    }

    public String getYhlxb() {
        return yhlxb;
    }

    public void setYhlxb(String yhlxb) {
        this.yhlxb = yhlxb;
    }

    public String getYhwzsm() {
        return yhwzsm;
    }

    public void setYhwzsm(String yhwzsm) {
        this.yhwzsm = yhwzsm;
    }

    public String getHdmc() {
        return hdmc;
    }

    public void setHdmc(String hdmc) {
        this.hdmc = hdmc;
    }

    public String getHddm() {
        return hddm;
    }

    public void setHddm(String hddm) {
        this.hddm = hddm;
    }

    public String getYdfw() {
        return ydfw;
    }

    public void setYdfw(String ydfw) {
        this.ydfw = ydfw;
    }

    public Double getYdmj() {
        return ydmj;
    }

    public void setYdmj(Double ydmj) {
        this.ydmj = ydmj;
    }

    public String getHdwz() {
        return hdwz;
    }

    public void setHdwz(String hdwz) {
        this.hdwz = hdwz;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }
}
